# twine upload --repository-url https://upload.pypi.org/legacy/ dist/*
# python setup.py sdist
#  python -m twine upload --repository-url https://upload.pypi.org/legacy/ dist/*
# python -m twine upload -u DanielBR08 -p DWhouse130_ --repository-url https://upload.pypi.org/legacy/ dist/*
def add_numbers(num1, num2):
    return num1 + num2

def subtract_numbers(num1, num2):
    return num1 - num2

